@@ -13,7 +13,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2021 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2022 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -63,6 +63,7 @@ import requests
 import shutil
 import sys
 import fs
+import warnings
 
 from mslib import __version__
 from mslib.msui.mss_qt import ui_mainwindow as ui
@@ -425,6 +426,8 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         picker_default = config_loader(dataset="filepicker_default")
         self.add_plugin_submenu("FTML", "ftml", None, picker_default, plugin_type="Import")
         self.add_plugin_submenu("FTML", "ftml", None, picker_default, plugin_type="Export")
+        self.add_plugin_submenu("CSV", "csv", load_from_csv, picker_default, plugin_type="Import")
+        self.add_plugin_submenu("CSV", "csv", save_to_csv, picker_default, plugin_type="Export")
         self.add_plugins()
 
         preload_urls = config_loader(dataset="WMS_preload")
@@ -504,10 +507,8 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
 
     def add_plugins(self):
         picker_default = config_loader(dataset="filepicker_default")
-        self.add_plugin_submenu("CSV", "csv", load_from_csv, picker_default, plugin_type="Import")
-        self.add_plugin_submenu("CSV", "csv", save_to_csv, picker_default, plugin_type="Export")
-        self.import_plugins = {"CSV": (load_from_csv, "csv")}
-        self.export_plugins = {"CSV": (save_to_csv, "csv")}
+        self.import_plugins = {}
+        self.export_plugins = {}
         self.add_import_plugins(picker_default)
         self.add_export_plugins(picker_default)
 
@@ -586,7 +587,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
             self.export_plugins[name] = (imported_function, extension)
 
     def remove_plugins(self):
-        for name, _ in self.import_plugins:
+        for name, _ in self.import_plugins.items():
             full_name = "actionImportFlightTrack" + clean_string(name)
             actions = [_x for _x in self.menuImportFlightTrack.actions()
                        if _x.objectName() == full_name]
@@ -595,7 +596,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
             delattr(self, full_name)
         self.import_plugins = {}
 
-        for name, _ in self.export_plugins:
+        for name, _ in self.export_plugins.items():
             full_name = "actionExportFlightTrack" + clean_string(name)
             actions = [_x for _x in self.menuExportActiveFlightTrack.actions()
                        if _x.objectName() == full_name]
@@ -895,10 +896,10 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
             self.listViews.item(0).window.handle_force_close()
         self.listViews.clear()
         self.remove_plugins()
-        self.add_plugins()
         if self.mscolab.token is not None:
             self.mscolab.logout()
         read_config_file()
+        self.add_plugins()
 
     def open_config_editor(self):
         """
@@ -998,6 +999,8 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
 
 
 def main():
+    warnings.warn("In the next major version we will rename the mss command to msui"
+                  " and the module from mss_pyui to msui", DeprecationWarning)
     try:
         prefix = os.environ["CONDA_DEFAULT_ENV"]
     except KeyError:
